@@ -21,10 +21,13 @@ use std::{
 };
 use syn::{GenericArgument, ItemFn, PathArguments, ReturnType, Type, TypeParamBound};
 
+mod pgx_pg_sys_stub;
+
 pub mod operator_common;
 pub mod pg_config;
-mod pgx_pg_sys_stub;
+pub mod rewriter;
 pub mod sql_entity_graph;
+
 pub use pgx_pg_sys_stub::PgxPgSysStub;
 
 #[doc(hidden)]
@@ -560,6 +563,10 @@ pub fn anonymonize_lifetimes(value: &mut syn::Type) {
     }
 }
 
+pub fn versioned_so_name(extension_name: &str, extension_version: &str) -> String {
+    format!("{}-{}", extension_name, extension_version)
+}
+
 #[cfg(test)]
 mod tests {
     use crate::{parse_extern_attributes, ExternArgs};
