@@ -31,6 +31,7 @@ use crate::sql_entity_graph::{
     to_sql::ToSql,
     SqlGraphEntity, SqlGraphIdentifier,
 };
+use crate::versioned_so_name;
 
 /// A generator for SQL.
 ///
@@ -64,6 +65,8 @@ pub struct PgxSql {
     pub ords: HashMap<PostgresOrdEntity, NodeIndex>,
     pub hashes: HashMap<PostgresHashEntity, NodeIndex>,
     pub aggregates: HashMap<PgAggregateEntity, NodeIndex>,
+    pub extension_name: String,
+    pub versioned_so: bool,
 }
 
 #[derive(Debug, Clone, Copy, PartialEq, PartialOrd, Eq, Ord)]
@@ -79,6 +82,8 @@ impl PgxSql {
         type_mappings: impl Iterator<Item = RustSqlMapping>,
         source_mappings: impl Iterator<Item = RustSourceOnlySqlMapping>,
         entities: impl Iterator<Item = SqlGraphEntity>,
+        extension_name: String,
+        versioned_so: bool,
     ) -> eyre::Result<Self> {
         let mut graph = StableGraph::new();
 
@@ -229,6 +234,8 @@ impl PgxSql {
             graph_root: root,
             graph_bootstrap: bootstrap,
             graph_finalize: finalize,
+            extension_name: extension_name,
+            versioned_so,
         };
         this.register_types();
         Ok(this)
@@ -495,6 +502,16 @@ impl PgxSql {
             },
         );
     }
+
+    pub fn get_module_pathname(&self) -> String {
+        return if self.versioned_so {
+            let extname = &self.extension_name;
+            let extver = &self.control.default_version;
+            format!("$libdir/{}", versioned_so_name(extname, extver))
+        } else {
+            String::from("MODULE_PATHNAME")
+        };
+    }
 }
 
 #[tracing::instrument(level = "error", skip_all)]
